import os

from .. import env


class RequirementsSpec(object):
    '''
    Reads depedencies from a requirements.txt file
    and returns an Environment object from it.
    '''
    msg = None

    def __init__(self, filename=None, name=None, **kwargs):
        self.filename = filename
        self.name = name
        self.msg = None

    def _valid_file(self):
        if os.path.exists(self.filename):
            return True
        else:
            self.msg = "There is no requirements.txt"
            return False

    def _valid_name(self):
        if self.name is None:
            self.msg = "Environment with requirements.txt file needs a name"
            return False
        else:
            return True

    def can_handle(self):
        return self._valid_file() and self._valid_name()

    @property
    def environment(self):
        dependencies = []
        with open(self.filename) as reqfile:
            for line in reqfile:
                line = line.strip()
                if not line or line.startswith('#'):
                    continue
                dependencies.append(line)
        return env.Environment(
            name=self.name,
            dependencies=dependencies
        )



# Definition of the version number
import os
from io import open as io_open

__all__ = ["__version__"]

# major, minor, patch, -extra
version_info = 4, 22, 0

# Nice string for the version
__version__ = '.'.join(map(str, version_info))


# # auto -extra based on commit hash (if not tagged as release)
# scriptdir = os.path.dirname(__file__)
# gitdir = os.path.abspath(os.path.join(scriptdir, "..", ".git"))
# if os.path.isdir(gitdir):  # pragma: nocover
#     extra = None
#     # Open config file to check if we are in tqdm project
#     with io_open(os.path.join(gitdir, "config"), 'r') as fh_config:
#         if 'tqdm' in fh_config.read():
#             # Open the HEAD file
#             with io_open(os.path.join(gitdir, "HEAD"), 'r') as fh_head:
#                 extra = fh_head.readline().strip()
#             # in a branch => HEAD points to file containing last commit
#             if 'ref:' in extra:
#                 # reference file path
#                 ref_file = extra[5:]
#                 branch_name = ref_file.rsplit('/', 1)[-1]
#
#                 ref_file_path = os.path.abspath(os.path.join(gitdir, ref_file))
#                 # check that we are in git folder
#                 # (by stripping the git folder from the ref file path)
#                 if os.path.relpath(
#                         ref_file_path, gitdir).replace('\\', '/') != ref_file:
#                     # out of git folder
#                     extra = None
#                 else:
#                     # open the ref file
#                     with io_open(ref_file_path, 'r') as fh_branch:
#                         commit_hash = fh_branch.readline().strip()
#                         extra = commit_hash[:8]
#                         if branch_name != "master":
#                             extra += '.' + branch_name
#
#             # detached HEAD mode, already have commit hash
#             else:
#                 extra = extra[:8]
#
#     # Append commit hash (and branch) to version string if not tagged
#     if extra is not None:
#         try:
#             with io_open(os.path.join(gitdir, "refs", "tags",
#                                       'v' + __version__)) as fdv:
#                 if fdv.readline().strip()[:8] != extra[:8]:
#                     __version__ += '-' + extra
#         except Exception as e:
#             if "No such file" not in str(e):
#                 raise



# (c) 2012-2013 Continuum Analytics, Inc. / http://continuum.io
# All Rights Reserved
#
# conda is distributed under the terms of the BSD 3-clause license.
# Consult LICENSE.txt or http://opensource.org/licenses/BSD-3-Clause.
from __future__ import absolute_import, division, print_function, unicode_literals

import sys


def execute(args, parser):
    if not args.command:
        parser.print_help()
        return
    print("ERROR: The 'conda help' command is deprecated.\n"
          "Instead use 'conda %s --help'." % args.command,
          file=sys.stderr)
    return 1
